.. _ext-api:

*************
Extension API
*************

If you want to learn how to make Mopidy extensions, read :ref:`extensiondev`.

.. automodule:: mopidy.ext
    :synopsis: Extension API for extending Mopidy
    :members:
